
# Type: node property


A grouping for any property that holds between a node and a value

URI: [biolink:node_property](https://w3id.org/biolink/vocab/node_property)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children

 *  [aggregate statistic](aggregate_statistic.md)
 *  [association➞id](association_id.md)
 *  [category](category.md)
 *  [creation date](creation_date.md)
 *  [description](description.md)
 *  [distribution](distribution.md)
 *  [downloadURL](downloadURL.md)
 *  [filler](filler.md)
 *  [full name](full_name.md)
 *  [genome build](genome_build.md)
 *  [has biological sequence](has_biological_sequence.md)
 *  [has chemical formula](has_chemical_formula.md)
 *  [has drug](has_drug.md)
 *  [has gene](has_gene.md)
 *  [has receptor](has_receptor.md)
 *  [has route](has_route.md)
 *  [has stressor](has_stressor.md)
 *  [has zygosity](has_zygosity.md)
 *  [id](id.md)
 *  [interbase coordinate](interbase_coordinate.md)
 *  [iri](iri.md)
 *  [latitude](latitude.md)
 *  [longitude](longitude.md)
 *  [name](name.md)
 *  [phase](phase.md)
 *  [retrievedOn](retrievedOn.md)
 *  [source data file](source_data_file.md)
 *  [source version](source_version.md)
 *  [source web page](source_web_page.md)
 *  [synonym](synonym.md)
 *  [systematic synonym](systematic_synonym.md)
 *  [timepoint](timepoint.md)
 *  [title](title.md)
 *  [type](type.md)
 *  [update date](update_date.md)
 *  [versionOf](versionOf.md)

## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [ActivityAndBehavior](ActivityAndBehavior.md)
 * [AdministrativeEntity](AdministrativeEntity.md)
 * [AnatomicalEntity](AnatomicalEntity.md)
 * [Attribute](Attribute.md)
 * [BiologicalEntity](BiologicalEntity.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [BiologicalSex](BiologicalSex.md)
 * [Carbohydrate](Carbohydrate.md)
 * [Case](Case.md)
 * [Cell](Cell.md)
 * [CellLine](CellLine.md)
 * [CellularComponent](CellularComponent.md)
 * [ChemicalExposure](ChemicalExposure.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [ClinicalEntity](ClinicalEntity.md)
 * [ClinicalIntervention](ClinicalIntervention.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [ClinicalTrial](ClinicalTrial.md)
 * [CodingSequence](CodingSequence.md)
 * [ConfidenceLevel](ConfidenceLevel.md)
 * [DataFile](DataFile.md)
 * [DataSet](DataSet.md)
 * [DataSetSummary](DataSetSummary.md)
 * [DataSetVersion](DataSetVersion.md)
 * [Device](Device.md)
 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [DistributionLevel](DistributionLevel.md)
 * [Drug](Drug.md)
 * [DrugExposure](DrugExposure.md)
 * [EnvironmentalFeature](EnvironmentalFeature.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [EvidenceType](EvidenceType.md)
 * [Exon](Exon.md)
 * [ExposureEvent](ExposureEvent.md)
 * [FrequencyValue](FrequencyValue.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOntologyClass](GeneOntologyClass.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [GenotypicSex](GenotypicSex.md)
 * [GeographicLocation](GeographicLocation.md)
 * [GeographicLocationAtTime](GeographicLocationAtTime.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)
 * [Haplotype](Haplotype.md)
 * [IndividualOrganism](IndividualOrganism.md)
 * [InformationContentEntity](InformationContentEntity.md)
 * [LifeStage](LifeStage.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [MaterialSample](MaterialSample.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularActivity](MolecularActivity.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NamedThing](NamedThing.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Occurrent](Occurrent.md)
 * [Onset](Onset.md)
 * [OntologyClass](OntologyClass.md)
 * [OrganismTaxon](OrganismTaxon.md)
 * [OrganismalEntity](OrganismalEntity.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [PhysicalEntity](PhysicalEntity.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [PlanetaryEntity](PlanetaryEntity.md)
 * [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)
 * [Procedure](Procedure.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [Provider](Provider.md)
 * [Publication](Publication.md)
 * [RelationshipType](RelationshipType.md)
 * [SequenceVariant](SequenceVariant.md)
 * [SeverityValue](SeverityValue.md)
 * [SourceFile](SourceFile.md)
 * [Transcript](Transcript.md)
 * [Treatment](Treatment.md)
 * [Zygosity](Zygosity.md)
